summaryrefslogtreecommitdiff
path: root/chromium/net/third_party/quiche/src/quiche/quic/qbone/qbone_client.h
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2022-11-28 16:14:41 +0100
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2022-12-13 15:19:41 +0000
commit61d9742824d54be5693191fe502325a909feca59 (patch)
treecbf28e779b11338fe52eb75b915684cd8955542c /chromium/net/third_party/quiche/src/quiche/quic/qbone/qbone_client.h
parent45f9ded08bb7526984b24ccb5a5327aaf6821676 (diff)
downloadqtwebengine-chromium-61d9742824d54be5693191fe502325a909feca59.tar.gz
BASELINE: Update Chromium to 108.0.5359.70
Change-Id: I77334ff232b819600f275bd3cfe41fbaa3619230 Reviewed-on: https://codereview.qt-project.org/c/qt/qtwebengine-chromium/+/445904 Reviewed-by: Allan Sandfeld Jensen <allan.jensen@qt.io>
Diffstat (limited to 'chromium/net/third_party/quiche/src/quiche/quic/qbone/qbone_client.h')
-rw-r--r--chromium/net/third_party/quiche/src/quiche/quic/qbone/qbone_client.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/chromium/net/third_party/quiche/src/quiche/quic/qbone/qbone_client.h b/chromium/net/third_party/quiche/src/quiche/quic/qbone/qbone_client.h
index 5f52679b326..cda71da3326 100644
--- a/chromium/net/third_party/quiche/src/quiche/quic/qbone/qbone_client.h
+++ b/chromium/net/third_party/quiche/src/quiche/quic/qbone/qbone_client.h
@@ -6,24 +6,24 @@
#define QUICHE_QUIC_QBONE_QBONE_CLIENT_H_
#include "absl/strings/string_view.h"
+#include "quiche/quic/core/io/quic_event_loop.h"
#include "quiche/quic/qbone/qbone_client_interface.h"
#include "quiche/quic/qbone/qbone_client_session.h"
#include "quiche/quic/qbone/qbone_packet_writer.h"
#include "quiche/quic/tools/quic_client_base.h"
-#include "quiche/quic/tools/quic_client_epoll_network_helper.h"
namespace quic {
// A QboneClient encapsulates connecting to a server via an epoll server
// and setting up a QBONE tunnel. See the QboneTestClient in qbone_client_test
// for usage.
class QboneClient : public QuicClientBase, public QboneClientInterface {
public:
// Note that the epoll server, QBONE writer, and handler are owned
// by the caller.
QboneClient(QuicSocketAddress server_address, const QuicServerId& server_id,
const ParsedQuicVersionVector& supported_versions,
QuicSession::Visitor* session_owner, const QuicConfig& config,
- QuicEpollServer* epoll_server,
+ QuicEventLoop* event_loop,
std::unique_ptr<ProofVerifier> proof_verifier,
QbonePacketWriter* qbone_writer,
QboneClientControlStream::Handler* qbone_handler);
@@ -6,24 +6,24 @@
namespace quic {
-// A QboneClient encapsulates connecting to a server via an epoll server
+// A QboneClient encapsulates connecting to a server via an event loop
// and setting up a QBONE tunnel. See the QboneTestClient in qbone_client_test
// for usage.
@@ -6,24 +6,24 @@
class QboneClient : public QuicClientBase, public QboneClientInterface {
public:
- // Note that the epoll server, QBONE writer, and handler are owned
+ // Note that the event loop, QBONE writer, and handler are owned
// by the caller.
QboneClient(QuicSocketAddress server_address, const QuicServerId& server_id,